/*
 * roboShield Example
 * Control 8 servos
 * Control 2 motors including direction
 * only using i2c pins
 * This example creates 2 instances of the PCA9685 library
 * servos can be controlled from either instance
 * motor 1 is controlled by instance servos_Motor1
 * motor 2 is controlled by instance servos_Motor2
 * The library is a mash of PCA9685 and TB6612FNG libraries.
 * The PCA9685 has 16 PWM capable outputs.  8 are utilized as servo control and 7 are connected to the TB6612FNG
 *  for control of 2 motors
 * 
 */
//*** USE NANO OLD BOOTLOADER!!!!


#include <Wire.h>
#include "ESC.h"
#include "SCMD.h"
#include "SCMD_config.h" //Contains #defines for common SCMD register names and values
SCMD myMotorDriver; //This creates the main object of one motor driver and connected slaves.


#define SPEED_MIN (1500)                                  // Set the Minimum Speed in microseconds
#define SPEED_MAX (3000)                                  // Set the Minimum Speed in microseconds

ESC myESC (9, SPEED_MIN, SPEED_MAX, 500);                 // ESC_Name (ESC PIN, Minimum Value, Maximum Value, Default Speed, Arm Value)
int oESC;  

int sp = -0x1000;
int srv = -90, dir = 1;
int val = 3800;
int val1 = 900;
void setup() {
    Serial.begin(9600);

    Wire.begin();                      // Wire must be started first
    Wire.setClock(400000);             // Supported baud rates are 100kHz, 400kHz, and 1000kHz
    delay(500);
    Serial.println("ESC");
    myESC.arm();   
    Serial.println("MOTOR");
 //***** Configure the Motor Driver's Settings *****//
  //  .commInter face can be I2C_MODE or SPI_MODE
  myMotorDriver.settings.commInterface = I2C_MODE;
  //myMotorDriver.settings.commInterface = SPI_MODE;

  //  set address if I2C configuration selected with the config jumpers
  myMotorDriver.settings.I2CAddress = 0x5D; //config pattern "0101" on board for address 0x5A

  //  set chip select if SPI selected with the config jumpers
  myMotorDriver.settings.chipSelectPin = 10;

  //*****initialize the driver get wait for idle*****//
  while ( myMotorDriver.begin() != 0xA9 ) //Wait until a valid ID word is returned
  {
    Serial.println( "ID mismatch, trying again" );
    delay(500);
  }
  Serial.println( "ID matches 0xA9" );

  //  Check to make sure the driver is done looking for slaves before beginning
  Serial.print("Waiting for enumeration...");
  while ( myMotorDriver.ready() == false );
  Serial.println("Done.");
  Serial.println();

  //*****Set application settings and enable driver*****//

  while ( myMotorDriver.busy() );
  myMotorDriver.enable();

    
}

void loop() {
  
  //pwmController.setChannelPWM(13, 0);
  
  int anVal1 = analogRead(1);
  int anVal0 = analogRead(0);
    
  int rotationVal;
  
  int propellerVal = map(anVal0,760,280,1500,2500); 


  if (propellerVal < 0)
    propellerVal = 0;
    
  if (anVal1 >= 540){
    dir = 0;
    rotationVal = map(anVal1,540,750,0,255);
  }
  else{
    dir = 1;
    rotationVal = map(anVal1,290,540,255,0);
  }
  if (propellerVal < 1700)
    rotationVal = 0;
      
  myMotorDriver.setDrive( 0, dir, rotationVal);
  
  
  myESC.speed(propellerVal);  
  Serial.print("Rot:");
  Serial.print(anVal1);
  Serial.print(",");
  Serial.print(rotationVal);
  Serial.print("  Prop:");
  Serial.print(anVal0);
  Serial.print(",");  
  Serial.println(propellerVal);
  
  delay(50);
  
}
